@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Dpkg::PerlbrewStarman;
 {
-  $Dist::Zilla::Plugin::Dpkg::PerlbrewStarman::VERSION = '0.12';
+  $Dist::Zilla::Plugin::Dpkg::PerlbrewStarman::VERSION = '0.13';
 }
 use Moose;
 
@@ -277,17 +277,17 @@ PACKAGE={$package_name}
 case "$1" in
     purge)
         # Remove the config symlink
-        rm /etc/$PACKAGE
+        rm -f /etc/$PACKAGE
 
         # Remove the nginx config
         if [ -h /etc/nginx/sites-available/$PACKAGE ]; then
-            rm /etc/nginx/sites-available/$PACKAGE
+            rm -f /etc/nginx/sites-available/$PACKAGE
         fi
 
         # Remove the apache config
         if [ -e /etc/apache2/sites-available/$PACKAGE ]; then
-            rm /etc/apache2/sites-enabled/$PACKAGE
-            rm /etc/apache2/sites-available/$PACKAGE
+            rm -f /etc/apache2/sites-enabled/$PACKAGE
+            rm -f /etc/apache2/sites-available/$PACKAGE
         fi
 
         # Remove the user
@@ -420,7 +420,7 @@ Dist::Zilla::Plugin::Dpkg::PerlbrewStarman - Generate dpkg files for your perlbr
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
